/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:RulesManagerModelLocator.as 2485 2008-09-30 14:14:35Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.manager.model
{

import com.adobe.cairngorm.model.ModelLocator;

import org.ow2.jasmine.monitoring.eos.rules.manager.business.*;
import org.ow2.jasmine.monitoring.eos.rules.manager.model.domain.*;
import org.ow2.jasmine.monitoring.eos.rules.manager.model.presentation.*;
	
/**
* Cairngorm Model Locator for the rule manager component
* 
* @author Julien Nicoulaud
*/
[Bindable]
public class RuleManagerModelLocator implements ModelLocator 
{
    // =========================================================================
    // Variables
    // =========================================================================
            
    /**
    * Singleton instance of this locator
    */
	private static var instance:RuleManagerModelLocator;
	
	
    // Models
    
    /**
    * Rule manager domain model
    */
    public var ruleManagerModel:RuleManagerModel;
    
    /**
    * Rule manager presentation model
    */
    public var ruleManagerPresentationModel:RuleManagerPM;

    
    // Command delegates unique instances
    
    /**
    * GetRulePackages delegate unique instance
    */
    private var getRulePackagesDelegate:IGetRulePackagesDelegate = null;
    
    /**
    * SaveRulePackage delegate unique instance
    */
    private var saveRulePackageDelegate:ISaveRulePackageDelegate = null;
    
    /**
    * DeleteRulePackage delegate unique instance
    */
    private var deleteRulePackageDelegate:IDeleteRulePackageDelegate = null;

    /**
    * CompileRulePackage delegate unique instance
    */
    private var compileRulePackageDelegate:ICompileRulePackageDelegate = null;

    /**
    * ExportRulePackagesAsXML delegate unique instance
    */
    private var exportRulePackagesAsXMLDelegate:IExportRulePackagesAsXMLDelegate = null;
            
            
    // =========================================================================
    // Construction and singleton instance access
    // =========================================================================
    
    /**
    * Constructor
    */
	public function RuleManagerModelLocator()
	{
		// Instanciate the singleton
		if(instance!=null) {
			throw new Error("Error: Singletons can only be" + 
							"instantiated via getInstance() method!");
		}
		RuleManagerModelLocator.instance = this;
	}
	
	/**
	* RuleManagerModelLocator singleton instance getter
	*/
	public static function getInstance():RuleManagerModelLocator
	{
		if(instance==null){
            
            // Instanciate the ModelLocator
            instance = new RuleManagerModelLocator();
            
            // Instanciate the models
            instance.ruleManagerModel = new RuleManagerModel();
            instance.ruleManagerPresentationModel = new RuleManagerPM(instance.ruleManagerModel);
            
        }
		return instance;
	}
	
	
    // =========================================================================
    // Delegates getters
    // =========================================================================
    
    /**
    * "Get rule packages" delegate getter
    */
    public function getGetRulePackagesDelegate():IGetRulePackagesDelegate {
        if (this.getRulePackagesDelegate == null) {
            this.getRulePackagesDelegate = new GetRulePackagesDelegate();
        }
        return this.getRulePackagesDelegate;
    }
    
    /**
    * "Save rule package" delegate getter
    */
    public function getSaveRulePackageDelegate():ISaveRulePackageDelegate {
        if (this.saveRulePackageDelegate == null) {
            this.saveRulePackageDelegate = new SaveRulePackageDelegate();
        }
        return this.saveRulePackageDelegate;
    }
    
    /**
    * "Delete rule package" delegate getter
    */
    public function getDeleteRulePackageDelegate():IDeleteRulePackageDelegate {
        if (this.deleteRulePackageDelegate == null) {
            this.deleteRulePackageDelegate = new DeleteRulePackageDelegate();
        }
        return this.deleteRulePackageDelegate;
    }

    /**
    * "Compile rule package" delegate getter
    */
    public function getCompileRulePackageDelegate():ICompileRulePackageDelegate {
        if (this.compileRulePackageDelegate == null) {
            this.compileRulePackageDelegate = new CompileRulePackageDelegate();
        }
        return this.compileRulePackageDelegate;
    }

    /**
    * "Export rule packages as XML" delegate getter
    */
    public function getExportRulePackagesAsXMLDelegate():IExportRulePackagesAsXMLDelegate {
        if (this.exportRulePackagesAsXMLDelegate == null) {
            this.exportRulePackagesAsXMLDelegate = new ExportRulePackagesAsXMLDelegate();
        }
        return this.exportRulePackagesAsXMLDelegate;
    }
}
}